@@ -29,12 +29,9 @@ class PythonExecutor:
 
     def run_function(self, request: ExecutionRequest) -> ExecutionResponse:
         logging.debug("Prepare to run function `%s`", request.function_name)
-        logging.debug("Module `%s`", request.function_module)
-        logging.debug("Imports `%s`", request.imports)
         try:
             memory_dump = deserialize_memory_objects(request.serialized_memory)
             loader = DumpLoader(memory_dump)
-            logging.debug("loader `%s`", loader)
         except Exception as ex:
             logging.debug("Error \n%s", traceback.format_exc())
             return ExecutionFailResponse("fail", traceback.format_exc())
@@ -42,10 +39,8 @@ class PythonExecutor:
         try:
             self.add_syspaths(request.syspaths)
             self.add_imports(request.imports)
-            logging.debug("self imports OK")
             loader.add_syspaths(request.syspaths)
             loader.add_imports(request.imports)
-            logging.debug("loader imports OK")
         except Exception as ex:
             logging.debug("Error \n%s", traceback.format_exc())
             return ExecutionFailResponse("fail", traceback.format_exc())
@@ -55,9 +50,7 @@ class PythonExecutor:
                     importlib.import_module(request.function_module),
                     request.function_name
                     )
-            logging.debug("Function OK")
             args = [loader.load_object(PythonId(arg_id)) for arg_id in request.arguments_ids]
-            logging.debug("Arguments OK")
             kwargs: dict[str, Any] = {}
         except Exception as ex:
             logging.debug("Error \n%s", traceback.format_exc())
@@ -70,11 +63,9 @@ class PythonExecutor:
                     kwargs,
                     request.filepath
                     )
-            logging.debug("Value OK")
         except Exception as ex:
             logging.debug("Error \n%s", traceback.format_exc())
             return ExecutionFailResponse("fail", traceback.format_exc())
-        logging.debug("Function execution: done")
         return value
 
 
